Translation class abstract

Translation returned from GoogleTranslator.translate method, containing the translated text, the source text, the translated language and the source language

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
final
sourceLanguage → Language
final
targetLanguage → Language
final
text → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator +(Translation other) → String
operator ==(Object other) → bool
The equality operator.
inherited